﻿using Microsoft.Office.Tools;
using System;
using System.Diagnostics;
using System.IO;
using System.Reflection;

namespace TestProject
{
    /// <summary>
    /// 커스텀 애드인
    /// </summary>
    public partial class CustomAddIn
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 커스텀 컨트롤
        /// </summary>
        private CustomControl customControl;
        
        /// <summary>
        /// 커스텀 태스크 창
        /// </summary>
        private CustomTaskPane customTaskPane;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 커스텀 애드인 시작시 처리하기 - CustomAddIn_Startup(sender, e)

        /// <summary>
        /// 커스텀 애드인 시작시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void CustomAddIn_Startup(object sender, EventArgs e)
        {
            #region 프로그램 디렉토리 경로를 설정한다.

            string programDirectoryPath = "c:\\DSCore\\TestProject";

            #endregion
            #region 프로그램 디렉토리가 없는 경우 생성한다.

            if (!Directory.Exists(programDirectoryPath))
            {
                Directory.CreateDirectory(programDirectoryPath);
            }

            #endregion

            #region 로그 디렉토리 경로를 설정한다.

            string logDirectoryPath = Path.Combine(programDirectoryPath, "Log");

            #endregion
            #region 로그 디렉토리가 없는 경우 생성한다.

            if (!Directory.Exists(logDirectoryPath))
            {
                Directory.CreateDirectory(logDirectoryPath);
            }

            #endregion
            #region 로그 헬퍼를 설정한다.

            ILogHelper logHelper = new FileLogHelper(logDirectoryPath, "test.log");

            #endregion

            #region 실행 디렉토리 경로를 설정한다.

            string executingDirectoryPath = Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location);
            
            logHelper?.WriteLog($"EXECUTING DIRECTORY PATH : {executingDirectoryPath}");

            #endregion

            #region 업데이터를 실행한다.

            try
            {
                string updaterPath = Path.Combine(programDirectoryPath, "updater.exe");

                logHelper?.WriteLog($"UPDATER PATH : {updaterPath}");

                if(File.Exists(updaterPath))
                {
                    Process process = Process.Start(updaterPath, "/silentall");

                    process.WaitForExit();

                    logHelper?.WriteLog($"UPDATER PROCESS EXIT CODE : {process.ExitCode}");

                    if(process.ExitCode == 0)
                    {
                        return;
                    }
                }
            }
            catch(Exception exception)
            {
                logHelper?.WriteErrorLog(exception, "ERROR EXECUTE UPDATER");
            }

            #endregion

            #region 테스트 태스크 창을 추가한다.

            this.customControl = new CustomControl();

            this.customTaskPane = CustomTaskPanes.Add(this.customControl, "테스트 태스크 창");

            this.customTaskPane.Visible = true;

            #endregion
        }

        #endregion
        #region 커스텀 애드인 셧다운시 처리하기 - CustomAddIn_Shutdown(sender, e)

        /// <summary>
        /// 커스텀 애드인 셧다운시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void CustomAddIn_Shutdown(object sender, EventArgs e)
        {
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region VSTO에서 생성한 코드

        /// <summary>
        /// 디자이너 지원에 필요한 메서드입니다. 
        /// 이 메서드의 내용을 코드 편집기로 수정하지 마세요.
        /// </summary>
        private void InternalStartup()
        {
            this.Startup  += new System.EventHandler(CustomAddIn_Startup );
            this.Shutdown += new System.EventHandler(CustomAddIn_Shutdown);
        }
        
        #endregion
    }
}